# --------------------------------------------------------
# This file contains SQL code to create "computer_hardware" database
# and its tables.
# --------------------------------------------------------

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET NAMES utf8 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;

CREATE DATABASE IF NOT EXISTS computer_hardware /*!40100 DEFAULT CHARACTER SET utf8 */;
USE computer_hardware;

/* Lookup: Values like Serial-ATA, Parallel-ATA */
CREATE TABLE IF NOT EXISTS bus_interfaces (
  bus_interface_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  bus_interface_name varchar(100) NOT NULL,
  PRIMARY KEY (bus_interface_id),
  UNIQUE KEY bus_interface_name (bus_interface_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like BIG-tower, MINI-tower */
CREATE TABLE IF NOT EXISTS computer_case_sizes (
  computer_case_size_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  computer_case_size_name varchar(100) NOT NULL,
  PRIMARY KEY (computer_case_size_id),
  UNIQUE KEY computer_case_size_name (computer_case_size_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like 120mm, 80mm */
CREATE TABLE IF NOT EXISTS cooling_fan_sizes (
  cooling_fan_size_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  cooling_fan_size_diameter_mm int(11) NOT NULL,
  PRIMARY KEY (cooling_fan_size_id),
  UNIQUE KEY cooling_fan_size_diameter_mm (cooling_fan_size_diameter_mm)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like 3.5inch, 5.25inch */
CREATE TABLE IF NOT EXISTS drive_bay_widths (
  drive_bay_width_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  drive_bay_width_name varchar(100) NOT NULL,
  PRIMARY KEY (drive_bay_width_id),
  UNIQUE KEY drive_bay_width_name (drive_bay_width_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like Fast Ethernet, Gigabit Ethernet */
CREATE TABLE IF NOT EXISTS ethernet_standards (
  ethernet_standard_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  ethernet_standard_name varchar(100) NOT NULL,
  PRIMARY KEY (ethernet_standard_id),
  UNIQUE KEY ethernet_standard_name (ethernet_standard_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like PCI Express, ISA */
CREATE TABLE IF NOT EXISTS expansion_slots (
  expansion_slot_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  expansion_slot_name varchar(100) NOT NULL,
  PRIMARY KEY (expansion_slot_id),
  UNIQUE KEY expansion_slot_name (expansion_slot_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like SMART, Native Command Queuing */
CREATE TABLE IF NOT EXISTS hard_drive_features (
  hard_drive_feature_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  hard_drive_feature_name varchar(100) NOT NULL,
  PRIMARY KEY (hard_drive_feature_id),
  UNIQUE KEY hard_drive_feature_name (hard_drive_feature_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like Philips, Seagate */
CREATE TABLE IF NOT EXISTS manufacturers (
  manufacturer_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  manufacturer_name varchar(100) NOT NULL,
  PRIMARY KEY (manufacturer_id),
  UNIQUE KEY manufacturer_name (manufacturer_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like DDR SDRAM, GDDR3 */
CREATE TABLE IF NOT EXISTS memory_types (
  memory_type_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  memory_type_name varchar(100) NOT NULL,
  PRIMARY KEY (memory_type_id),
  UNIQUE KEY memory_type_name (memory_type_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like microATX, AT */
CREATE TABLE IF NOT EXISTS motherboard_form_factors (
  motherboard_form_factor_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  motherboard_form_factor_name varchar(100) NOT NULL,
  PRIMARY KEY (motherboard_form_factor_id),
  UNIQUE KEY motherboard_form_factor_name (motherboard_form_factor_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like DVD+R9 Dual Layer, DVD-R */
CREATE TABLE IF NOT EXISTS optical_disk_formats (
  optical_disk_format_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  optical_disk_format_name varchar(100) NOT NULL,
  PRIMARY KEY (optical_disk_format_id),
  UNIQUE KEY optical_disk_format_name (optical_disk_format_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like LightScribe, Buffer Underrun Protection */
CREATE TABLE IF NOT EXISTS optical_drive_features (
  optical_drive_feature_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  optical_drive_feature_name varchar(100) NOT NULL,
  PRIMARY KEY (optical_drive_feature_id),
  UNIQUE KEY optical_drive_feature_name (optical_drive_feature_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like USB 2.0, RS-232 */
CREATE TABLE IF NOT EXISTS peripheral_interfaces (
  peripheral_interface_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  peripheral_interface_name varchar(100) NOT NULL,
  PRIMARY KEY (peripheral_interface_id),
  UNIQUE KEY peripheral_interface_name (peripheral_interface_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like ATX12V v2.01, ATX12V v2.3 */
CREATE TABLE IF NOT EXISTS power_supply_standards (
  power_supply_standard_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  power_supply_standard_name varchar(100) NOT NULL,
  PRIMARY KEY (power_supply_standard_id),
  UNIQUE KEY power_supply_standard_name (power_supply_standard_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like LGA 775, Socket AM3 */
CREATE TABLE IF NOT EXISTS processor_sockets (
  processor_socket_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  processor_socket_name varchar(100) NOT NULL,
  PRIMARY KEY (processor_socket_id),
  UNIQUE KEY processor_socket_name (processor_socket_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* Lookup: Values like 2.0 Stereo, 5.1 */
CREATE TABLE IF NOT EXISTS sound_channel_standards (
  sound_channel_standard_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  sound_channel_standard_name varchar(100) NOT NULL,
  PRIMARY KEY (sound_channel_standard_id),
  UNIQUE KEY sound_channel_standard_name (sound_channel_standard_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS motherboard_nb_chipsets (
  motherboard_nb_chipset_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  motherboard_nb_chipset_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  PRIMARY KEY (motherboard_nb_chipset_id),
  UNIQUE KEY motherboard_nb_chipset_name (motherboard_nb_chipset_name),
  KEY manufacturer_id (manufacturer_id),
  CONSTRAINT motherboard_nb_chipsets_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS motherboard_sb_chipsets (
  motherboard_sb_chipset_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  motherboard_sb_chipset_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  PRIMARY KEY (motherboard_sb_chipset_id),
  UNIQUE KEY motherboard_sb_chipset_name (motherboard_sb_chipset_name),
  KEY manufacturer_id (manufacturer_id),
  CONSTRAINT motherboard_sb_chipsets_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS gpus (
  gpu_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  gpu_name varchar(100) NOT NULL,
  gpu_core_name varchar(100) NOT NULL,
  gpu_directx_version varchar(100) NOT NULL,
  gpu_opengl_version varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  PRIMARY KEY (gpu_id),
  UNIQUE KEY gpu_name (gpu_name),
  KEY manufacturer_id (manufacturer_id),
  CONSTRAINT gpus_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS lan_chips (
  lan_chip_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  lan_chip_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  ethernet_standard_id int(10) unsigned NOT NULL,
  PRIMARY KEY (lan_chip_id),
  UNIQUE KEY lan_chip_name (lan_chip_name),
  KEY manufacturer_id (manufacturer_id),
  KEY ethernet_standard_id (ethernet_standard_id),
  CONSTRAINT lan_chips_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE,
  CONSTRAINT lan_chips_ibfk_2 FOREIGN KEY (ethernet_standard_id) REFERENCES ethernet_standards (ethernet_standard_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS sound_chips (
  sound_chip_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  sound_chip_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  sound_channel_standard_id int(10) unsigned NOT NULL,
  PRIMARY KEY (sound_chip_id),
  UNIQUE KEY sound_chip_name (sound_chip_name),
  KEY manufacturer_id (manufacturer_id),
  KEY sound_channel_standard_id (sound_channel_standard_id),
  CONSTRAINT sound_chips_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE,
  CONSTRAINT sound_chips_ibfk_2 FOREIGN KEY (sound_channel_standard_id) REFERENCES sound_channel_standards (sound_channel_standard_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS computer_cases (
  computer_case_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  computer_case_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  motherboard_form_factor_id int(10) unsigned NOT NULL,
  computer_case_size_id int(10) unsigned NOT NULL,
  front_usb_connector_count int(11) NOT NULL,
  depth_mm int(11) NOT NULL,
  width_mm int(11) NOT NULL,
  height_mm int(11) NOT NULL,
  weight_kg float NOT NULL,
  color varchar(100) NOT NULL,
  PRIMARY KEY (computer_case_id),
  KEY manufacturer_id (manufacturer_id),
  KEY motherboard_form_factor_id (motherboard_form_factor_id),
  KEY computer_case_size_id (computer_case_size_id),
  CONSTRAINT computer_cases_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE,
  CONSTRAINT computer_cases_ibfk_2 FOREIGN KEY (motherboard_form_factor_id) REFERENCES motherboard_form_factors (motherboard_form_factor_id) ON UPDATE CASCADE,
  CONSTRAINT computer_cases_ibfk_3 FOREIGN KEY (computer_case_size_id) REFERENCES computer_case_sizes (computer_case_size_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS hard_drives (
  hard_drive_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  hard_drive_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  bus_interface_id int(10) unsigned NOT NULL,
  drive_bay_width_id int(10) unsigned NOT NULL,
  buffer_kb int(10) unsigned NOT NULL,
  capacity_gb int(10) unsigned NOT NULL,
  PRIMARY KEY (hard_drive_id),
  KEY manufacturer_id (manufacturer_id),
  KEY bus_interface_id (bus_interface_id),
  KEY drive_bay_width_id (drive_bay_width_id),
  CONSTRAINT hard_drives_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE,
  CONSTRAINT hard_drives_ibfk_2 FOREIGN KEY (bus_interface_id) REFERENCES bus_interfaces (bus_interface_id) ON UPDATE CASCADE,
  CONSTRAINT hard_drives_ibfk_3 FOREIGN KEY (drive_bay_width_id) REFERENCES drive_bay_widths (drive_bay_width_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS memories (
  memory_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  memory_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  memory_type_id int(10) unsigned NOT NULL,
  memory_speed_mhz int(11) NOT NULL,
  memory_size_mb int(11) NOT NULL,
  PRIMARY KEY (memory_id),
  KEY manufacturer_id (manufacturer_id),
  KEY memory_type_id (memory_type_id),
  CONSTRAINT memories_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE,
  CONSTRAINT memories_ibfk_2 FOREIGN KEY (memory_type_id) REFERENCES memory_types (memory_type_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* atribut gpu_id nije definiran kao NOT NULL tako da je odnos izme�u mati�nih plo�a i grafi�kih �ipova one-to-many ali non-mandatory. To zna�i da mati�na plo�a mo�e imati integrirani video sustav i ne mora. */
CREATE TABLE IF NOT EXISTS motherboards (
  motherboard_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  motherboard_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  motherboard_nb_chipset_id int(10) unsigned NOT NULL,
  motherboard_sb_chipset_id int(10) unsigned NOT NULL,
  processor_socket_id int(10) unsigned NOT NULL,
  memory_type_id int(10) unsigned NOT NULL,
  motherboard_form_factor_id int(10) unsigned NOT NULL,
  gpu_id int(10) unsigned DEFAULT NULL,
  power_supply_standard_id int(10) unsigned NOT NULL,
  lan_chip_id int(10) unsigned NOT NULL,
  sound_chip_id int(10) unsigned NOT NULL,
  front_usb_header_count int(11) NOT NULL,
  PRIMARY KEY (motherboard_id),
  KEY manufacturer_id (manufacturer_id),
  KEY motherboard_nb_chipset_id (motherboard_nb_chipset_id),
  KEY motherboard_sb_chipset_id (motherboard_sb_chipset_id),
  KEY processor_socket_id (processor_socket_id),
  KEY memory_type_id (memory_type_id),
  KEY motherboard_form_factor_id (motherboard_form_factor_id),
  KEY gpu_id (gpu_id),
  KEY power_supply_standard_id (power_supply_standard_id),
  KEY lan_chip_id (lan_chip_id),
  KEY sound_chip_id (sound_chip_id),
  CONSTRAINT motherboards_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE,
  CONSTRAINT motherboards_ibfk_2 FOREIGN KEY (motherboard_nb_chipset_id) REFERENCES motherboard_nb_chipsets (motherboard_nb_chipset_id) ON UPDATE CASCADE,
  CONSTRAINT motherboards_ibfk_3 FOREIGN KEY (motherboard_sb_chipset_id) REFERENCES motherboard_sb_chipsets (motherboard_sb_chipset_id) ON UPDATE CASCADE,
  CONSTRAINT motherboards_ibfk_4 FOREIGN KEY (processor_socket_id) REFERENCES processor_sockets (processor_socket_id) ON UPDATE CASCADE,
  CONSTRAINT motherboards_ibfk_5 FOREIGN KEY (memory_type_id) REFERENCES memory_types (memory_type_id) ON UPDATE CASCADE,
  CONSTRAINT motherboards_ibfk_6 FOREIGN KEY (motherboard_form_factor_id) REFERENCES motherboard_form_factors (motherboard_form_factor_id) ON UPDATE CASCADE,
  CONSTRAINT motherboards_ibfk_7 FOREIGN KEY (gpu_id) REFERENCES gpus (gpu_id) ON UPDATE CASCADE,
  CONSTRAINT motherboards_ibfk_8 FOREIGN KEY (power_supply_standard_id) REFERENCES power_supply_standards (power_supply_standard_id) ON UPDATE CASCADE,
  CONSTRAINT motherboards_ibfk_9 FOREIGN KEY (lan_chip_id) REFERENCES lan_chips (lan_chip_id) ON UPDATE CASCADE,
  CONSTRAINT motherboards_ibfk_10 FOREIGN KEY (sound_chip_id) REFERENCES sound_chips (sound_chip_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS optical_drives (
  optical_drive_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  optical_drive_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  bus_interface_id int(10) unsigned NOT NULL,
  drive_bay_width_id int(10) unsigned NOT NULL,
  buffer_kb int(10) unsigned NOT NULL,
  PRIMARY KEY (optical_drive_id),
  KEY manufacturer_id (manufacturer_id),
  KEY bus_interface_id (bus_interface_id),
  KEY drive_bay_width_id (drive_bay_width_id),
  CONSTRAINT optical_drives_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE,
  CONSTRAINT optical_drives_ibfk_2 FOREIGN KEY (bus_interface_id) REFERENCES bus_interfaces (bus_interface_id) ON UPDATE CASCADE,
  CONSTRAINT optical_drives_ibfk_3 FOREIGN KEY (drive_bay_width_id) REFERENCES drive_bay_widths (drive_bay_width_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS power_supplies (
  power_supply_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  power_supply_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  motherboard_form_factor_id int(10) unsigned NOT NULL,
  power_supply_standard_id int(10) unsigned NOT NULL,
  cooling_fan_size_id int(10) unsigned NOT NULL,
  total_power_w int(10) unsigned NOT NULL,
  energy_efficiency_percentage int(10) unsigned NOT NULL,
  PRIMARY KEY (power_supply_id),
  KEY manufacturer_id (manufacturer_id),
  KEY motherboard_form_factor_id (motherboard_form_factor_id),
  KEY power_supply_standard_id (power_supply_standard_id),
  KEY cooling_fan_size_id (cooling_fan_size_id),
  CONSTRAINT power_supplies_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE,
  CONSTRAINT power_supplies_ibfk_2 FOREIGN KEY (motherboard_form_factor_id) REFERENCES motherboard_form_factors (motherboard_form_factor_id) ON UPDATE CASCADE,
  CONSTRAINT power_supplies_ibfk_3 FOREIGN KEY (power_supply_standard_id) REFERENCES power_supply_standards (power_supply_standard_id) ON UPDATE CASCADE,
  CONSTRAINT power_supplies_ibfk_4 FOREIGN KEY (cooling_fan_size_id) REFERENCES cooling_fan_sizes (cooling_fan_size_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS processors (
  processor_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  processor_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  processor_socket_id int(10) unsigned NOT NULL,
  processor_core_id int(10) unsigned NOT NULL,
  frequency_mhz int(10) unsigned NOT NULL,
  processor_power_consumption_w int(11) NOT NULL,
  PRIMARY KEY (processor_id),
  KEY processor_id (processor_id),
  KEY manufacturer_id (manufacturer_id),
  KEY processor_socket_id (processor_socket_id),
  KEY processor_core_id (processor_core_id),
  CONSTRAINT processors_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE,
  CONSTRAINT processors_ibfk_2 FOREIGN KEY (processor_socket_id) REFERENCES processor_sockets (processor_socket_id) ON UPDATE CASCADE,
  CONSTRAINT processors_ibfk_3 FOREIGN KEY (processor_core_id) REFERENCES processor_cores (processor_core_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS processor_cores (
  processor_core_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  processor_core_name varchar(100) NOT NULL,
  processor_core_count int(11) NOT NULL,
  processor_core_l1cache_kb int(11) NOT NULL,
  processor_core_l2cache_kb int(11) NOT NULL,
  processor_core_l3cache_kb int(11) NOT NULL,
  processor_core_manufacturing_technology_nm int(11) NOT NULL,
  PRIMARY KEY (processor_core_id),
  UNIQUE KEY processor_core_name (processor_core_name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS sound_cards (
  sound_card_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  sound_card_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  expansion_slot_id int(10) unsigned NOT NULL,
  sound_chip_id int(10) unsigned NOT NULL,
  PRIMARY KEY (sound_card_id),
  KEY manufacturer_id (manufacturer_id),
  KEY expansion_slot_id (expansion_slot_id),
  KEY sound_chip_id (sound_chip_id),
  CONSTRAINT sound_cards_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE,
  CONSTRAINT sound_cards_ibfk_2 FOREIGN KEY (expansion_slot_id) REFERENCES expansion_slots (expansion_slot_id) ON UPDATE CASCADE,
  CONSTRAINT sound_cards_ibfk_3 FOREIGN KEY (sound_chip_id) REFERENCES sound_chips (sound_chip_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS video_adapters (
  video_adapter_id int(10) unsigned NOT NULL AUTO_INCREMENT,
  video_adapter_name varchar(100) NOT NULL,
  manufacturer_id int(10) unsigned NOT NULL,
  expansion_slot_id int(10) unsigned NOT NULL,
  gpu_id int(10) unsigned NOT NULL,
  power_supply_standard_id int(10) unsigned NOT NULL,
  memory_type_id int(10) unsigned NOT NULL,
  video_adapter_memory_mb int(11) NOT NULL,
  PRIMARY KEY (video_adapter_id),
  KEY manufacturer_id (manufacturer_id),
  KEY expansion_slot_id (expansion_slot_id),
  KEY gpu_id (gpu_id),
  KEY power_supply_standard_id (power_supply_standard_id),
  KEY memory_type_id (memory_type_id),
  CONSTRAINT video_adapters_ibfk_1 FOREIGN KEY (manufacturer_id) REFERENCES manufacturers (manufacturer_id) ON UPDATE CASCADE,
  CONSTRAINT video_adapters_ibfk_2 FOREIGN KEY (expansion_slot_id) REFERENCES expansion_slots (expansion_slot_id) ON UPDATE CASCADE,
  CONSTRAINT video_adapters_ibfk_3 FOREIGN KEY (gpu_id) REFERENCES gpus (gpu_id) ON UPDATE CASCADE,
  CONSTRAINT video_adapters_ibfk_4 FOREIGN KEY (power_supply_standard_id) REFERENCES power_supply_standards (power_supply_standard_id) ON UPDATE CASCADE,
  CONSTRAINT video_adapters_ibfk_5 FOREIGN KEY (memory_type_id) REFERENCES memory_types (memory_type_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS l_hard_drives_hard_drive_features (
  hard_drive_id int(10) unsigned NOT NULL,
  hard_drive_feature_id int(10) unsigned NOT NULL,
  PRIMARY KEY (hard_drive_id,hard_drive_feature_id),
  KEY hard_drive_id (hard_drive_id),
  KEY hard_drive_feature_id (hard_drive_feature_id),
  CONSTRAINT l_hard_drives_hard_drive_features_ibfk_1 FOREIGN KEY (hard_drive_id) REFERENCES hard_drives (hard_drive_id) ON UPDATE CASCADE,
  CONSTRAINT l_hard_drives_hard_drive_features_ibfk_2 FOREIGN KEY (hard_drive_feature_id) REFERENCES hard_drive_features (hard_drive_feature_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS l_motherboards_expansion_slots (
  motherboard_id int(10) unsigned NOT NULL,
  expansion_slot_id int(10) unsigned NOT NULL,
  expansion_slot_count int(11) NOT NULL,
  PRIMARY KEY (motherboard_id,expansion_slot_id),
  KEY motherboard_id (motherboard_id),
  KEY expansion_slot_id (expansion_slot_id),
  CONSTRAINT l_motherboards_expansion_slots_ibfk_1 FOREIGN KEY (motherboard_id) REFERENCES motherboards (motherboard_id) ON UPDATE CASCADE,
  CONSTRAINT l_motherboards_expansion_slots_ibfk_2 FOREIGN KEY (expansion_slot_id) REFERENCES expansion_slots (expansion_slot_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS l_motherboard_bus_interfaces (
  motherboard_id int(10) unsigned NOT NULL,
  bus_interface_id int(10) unsigned NOT NULL,
  bus_interface_count int(11) NOT NULL,
  PRIMARY KEY (motherboard_id,bus_interface_id),
  KEY motherboard_id (motherboard_id),
  KEY bus_interface_id (bus_interface_id),
  CONSTRAINT l_motherboard_bus_interfaces_ibfk_1 FOREIGN KEY (motherboard_id) REFERENCES motherboards (motherboard_id) ON UPDATE CASCADE,
  CONSTRAINT l_motherboard_bus_interfaces_ibfk_2 FOREIGN KEY (bus_interface_id) REFERENCES bus_interfaces (bus_interface_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS l_motherboard_peripheral_interfaces (
  motherboard_id int(10) unsigned NOT NULL,
  peripheral_interface_id int(10) unsigned NOT NULL,
  peripheral_interface_count int(11) NOT NULL,
  PRIMARY KEY (motherboard_id,peripheral_interface_id),
  KEY motherboard_id (motherboard_id),
  KEY peripheral_interface_id (peripheral_interface_id),
  CONSTRAINT l_motherboard_peripheral_interfaces_ibfk_1 FOREIGN KEY (motherboard_id) REFERENCES motherboards (motherboard_id) ON UPDATE CASCADE,
  CONSTRAINT l_motherboard_peripheral_interfaces_ibfk_2 FOREIGN KEY (peripheral_interface_id) REFERENCES peripheral_interfaces (peripheral_interface_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS l_optical_drives_optical_disk_formats (
  optical_drive_id int(10) unsigned NOT NULL,
  optical_disk_format_id int(10) unsigned NOT NULL,
  optical_disk_format_write_speed int(11) NOT NULL,
  PRIMARY KEY (optical_drive_id,optical_disk_format_id),
  KEY optical_drive_id (optical_drive_id),
  KEY optical_disk_format_id (optical_disk_format_id),
  CONSTRAINT l_optical_drives_optical_disk_formats_ibfk_1 FOREIGN KEY (optical_drive_id) REFERENCES optical_drives (optical_drive_id) ON UPDATE CASCADE,
  CONSTRAINT l_optical_drives_optical_disk_formats_ibfk_2 FOREIGN KEY (optical_disk_format_id) REFERENCES optical_disk_formats (optical_disk_format_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS l_optical_drives_optical_drive_features (
  optical_drive_id int(10) unsigned NOT NULL,
  optical_drive_feature_id int(10) unsigned NOT NULL,
  PRIMARY KEY (optical_drive_id,optical_drive_feature_id),
  KEY optical_drive_id (optical_drive_id),
  KEY optical_drive_feature_id (optical_drive_feature_id),
  CONSTRAINT l_optical_drives_optical_drive_features_ibfk_1 FOREIGN KEY (optical_drive_id) REFERENCES optical_drives (optical_drive_id) ON UPDATE CASCADE,
  CONSTRAINT l_optical_drives_optical_drive_features_ibfk_2 FOREIGN KEY (optical_drive_feature_id) REFERENCES optical_drive_features (optical_drive_feature_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS l_computer_cases_cooling_fans (
  computer_case_id int(10) unsigned NOT NULL,
  cooling_fan_size_id int(10) unsigned NOT NULL,
  cooling_fan_size_count int(11) NOT NULL,
  PRIMARY KEY (computer_case_id,cooling_fan_size_id),
  KEY computer_case_id (computer_case_id),
  KEY cooling_fan_size_id (cooling_fan_size_id),
  CONSTRAINT l_computer_cases_cooling_fans_ibfk_1 FOREIGN KEY (computer_case_id) REFERENCES computer_cases (computer_case_id) ON UPDATE CASCADE,
  CONSTRAINT l_computer_cases_cooling_fans_ibfk_2 FOREIGN KEY (cooling_fan_size_id) REFERENCES cooling_fan_sizes (cooling_fan_size_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS l_computer_cases_drive_bay_widths (
  computer_case_id int(10) unsigned NOT NULL,
  drive_bay_width_id int(10) unsigned NOT NULL,
  drive_bay_width_count int(11) NOT NULL,
  PRIMARY KEY (computer_case_id,drive_bay_width_id),
  KEY computer_case_id (computer_case_id),
  KEY drive_bay_width_id (drive_bay_width_id),
  CONSTRAINT l_computer_cases_drive_bay_widths_ibfk_1 FOREIGN KEY (computer_case_id) REFERENCES computer_cases (computer_case_id) ON UPDATE CASCADE,
  CONSTRAINT l_computer_cases_drive_bay_widths_ibfk_2 FOREIGN KEY (drive_bay_width_id) REFERENCES drive_bay_widths (drive_bay_width_id) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
